isAuthenticated method
Whether a token set is stored locally. Doesn't guarantee the access token is still valid — use ensureFreshTokens before making a call.
Implementation
Future<bool> isAuthenticated() async => await _storage.read() != null;
Whether a token set is stored locally. Doesn't guarantee the access token is still valid — use ensureFreshTokens before making a call.
Future<bool> isAuthenticated() async => await _storage.read() != null;