deviceId property
Stable identifier for this device/install, as scoped by whatever the native implementation ends up using (Keystore-attested id, vendor id, etc.) — not yet defined.
Implementation
final String deviceId;
Stable identifier for this device/install, as scoped by whatever the native implementation ends up using (Keystore-attested id, vendor id, etc.) — not yet defined.
final String deviceId;