redirectUrl property
Where the authorization server redirects back to after the user authenticates — a custom scheme or app link registered on both platforms and with the authorization server.
Implementation
final String redirectUrl;
Where the authorization server redirects back to after the user authenticates — a custom scheme or app link registered on both platforms and with the authorization server.
final String redirectUrl;